==> dtkwidget_2.0.9.3.orig.tar.gz: dtkwidget-2.0.9.3/translations/dtkwidget2_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>প্রাপ্তি স্বীকার</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>ভার্সন: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 রিলিজ হয়েছে %2 এর অধীনে</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>নিশ্চিত করুন</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>দয়াকরে নতুন শর্টকাট চাপুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>কোনোটিই নয়</translation>
    </message>
</context>
<context>
    <name>DSimpleListView</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1190"/>
        <source>No search result</source>
        <translation>অনুসন্ধানের কোনো ফলাফল নেই</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>পূর্বনির্ধারিত জিনিসে ফিরে যান</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>দয়াকরে নতুন শর্টকাট চাপুন</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>সাহায্য</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>সম্পর্কে</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>বের হয়ে যান</translation>
    </message>
</context>
</TS>

==> dtkwidget_2.0.9.17.orig.tar.gz: dtkwidget-2.0.9.17/translations/dtkwidget2_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>প্রাপ্তি স্বীকার</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>ভার্সন: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1 রিলিজ হয়েছে %2 এর অধীনে</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>কালো</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>সাদা</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>গাঢ় ধূসর</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>ধূসর</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>হালকা ধূসর</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>লাল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>সবুজ</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>নীল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>সবজে নীল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>ম্যাজেন্টা</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>হলুদ</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>গাঢ় লাল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>গাঢ় সবুজ</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>গাঢ় নীল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>গাঢ় সবজে নীল</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>গাঢ় ম্যাজেন্টা</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>গাঢ় হলুদ</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>বাতিল করুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>নিশ্চিত করুন</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>দয়াকরে নতুন শর্টকাট চাপুন</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>কোনোটিই নয়</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1235"/>
        <source>No search result</source>
        <translation>অনুসন্ধানের কোনো ফলাফল নেই</translation>
    </message>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>পূর্বনির্ধারিত জিনিসে ফিরে যান</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>দয়াকরে নতুন শর্টকাট চাপুন</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>সাহায্য</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>সম্পর্কে</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>বের হয়ে যান</translation>
    </message>
</context>
</TS>
